/**************************************************************************************
Author:			David Szybala
Program:		Unit_Converter.ms
Date:			4/11/11
Description:	This script will convert different types of units (i.e. length, time, etc)
***************************************************************************************/

try (destroyDialog unitConvertRollout) catch()

(--put script into local scope
	global unitConvertRollout
	local unitConMiniIniFile = getDir #plugcfg + "\\UnitConversionMini.ini"
	local unitConvertRolloutPos
	
	/**********************************************************************************************/
	fn Set_Length_Conversion =
	(
		local convertMM = #(1,0.1,0.001,0.000001,0.039370079,0.00328084,0.001093613,0.000000621)
		local convertCM = #(10,1,0.01,0.00001,0.393700787,0.032808399,0.010936133,0.000006214)
		local convertM = #(1000,100,1,0.001,39.37007874,3.280839895,1.093613298,0.00062137)
		local convertKM = #(1000000,100000,1000,1,39370.078740158,3280.839895013,1093.613298338,0.621369949)
		local convertIN = #(25.4,2.54,0.0254,0.0000254,1,0.083333333,0.027777778,0.000015783)
		local convertFT = #(304.8,30.48,0.3048,0.0003048,12,1,0.333333333,0.000189394)
		local convertYD = #(914.4,91.44,0.9144,0.0009144,36,3,1,0.000568181)
		local convertMI = #(1609347.2186944,160934.72186944,1609.347218694,1.609347219,63360.126720253,5280.010560021,1760.003520007,1)
		--local resultLabels = #("mm","cm","m","km","in","ft","yd","mi")
		local tempValue = 0.0
		
		case unitConvertRollout.toUnitDD.selection of
		(
			(1):tempValue = convertMM[unitConvertRollout.fromUnitDD.selection]
			(2):tempValue = convertCM[unitConvertRollout.fromUnitDD.selection]
			(3):tempValue = convertM[unitConvertRollout.fromUnitDD.selection]
			(4):tempValue = convertKM[unitConvertRollout.fromUnitDD.selection]
			(5):tempValue = convertIN[unitConvertRollout.fromUnitDD.selection]
			(6):tempValue = convertFT[unitConvertRollout.fromUnitDD.selection]
			(7):tempValue = convertYD[unitConvertRollout.fromUnitDD.selection]
			(8):tempValue = convertMI[unitConvertRollout.fromUnitDD.selection]
		)--end case
		
		unitConvertRollout.resultLbl.text = ((unitConvertRollout.unitSpn.value / tempValue) as string)-- + resultLabels[unitConvertRollout.toUnitDD.selection]
	)--end fn
	
	/**********************************************************************************************/
	fn Set_Temp_Conversion =
	(
		--local resultLabels = #("C","F","K")
		local tempValue = 0.0
		
		--put everything into celcius
		case unitConvertRollout.fromUnitDD.selection of
		(
			(1):tempValue = unitConvertRollout.unitSpn.value
			(2):tempValue = (unitConvertRollout.unitSpn.value - 32) * .555556
			(3):tempValue = unitConvertRollout.unitSpn.value - 273.15
		)--end case
		
		case unitConvertRollout.toUnitDD.selection of
		(
			(2):tempValue = (tempValue * 1.8) + 32
			(3):tempValue = tempValue + 273.15
		)--end case
		
		unitConvertRollout.resultLbl.text = (tempValue as string)-- + resultLabels[unitConvertRollout.toUnitDD.selection]
	)--end fn
	
	/**********************************************************************************************/
	fn Set_Mass_Conversion =
	(
		local convertG = #(1,0.001,0.035273962,0.002204623,0.000001102)
		local convertKG = #(1000,1,0.028349523,0.45359237,0.001102311)
		local convertOZ = #(28.349523125,0.028349523,1,0.0625,0.00003125)
		local convertLB = #(453.59237,0.45359237,16,1,0.0005)
		local convertT = #(907184.74,907.18474,32000,2000,1)
		--local resultLabels = #("g","kg","oz","lb","t")
		local tempValue = 0.0
		
		case unitConvertRollout.toUnitDD.selection of
		(
			(1):tempValue = convertG[unitConvertRollout.fromUnitDD.selection]
			(2):tempValue = convertKG[unitConvertRollout.fromUnitDD.selection]
			(3):tempValue = convertOZ[unitConvertRollout.fromUnitDD.selection]
			(4):tempValue = convertLB[unitConvertRollout.fromUnitDD.selection]
			(5):tempValue = convertT[unitConvertRollout.fromUnitDD.selection]
		)--end case
		
		unitConvertRollout.resultLbl.text = ((unitConvertRollout.unitSpn.value / tempValue) as string)-- + resultLabels[unitConvertRollout.toUnitDD.selection]
	)--end fn
	
	/**********************************************************************************************/
	fn Set_Time_Conversion =
	(
		local convertMS = #(1,0.001,0.000016667,0.000000278,0,0,0,0)
		local convertS = #(1000,1,0.016666667,0.000277778,0.000011574,0.000001653,0,0)
		local convertMIN = #(60000,60,1,0.016666667,0.000694444,0.000099206,0.000022831,0.000001903)
		local convertHR = #(3600000,3600,60,1,0.041666667,0.005952381,0.001369863,0.000114155)
		local convertD = #(0,86400,1440,24,1,0.142857143,0.032876712,0.002739726)
		local convertWK = #(0,604800,10080,168,7,1,0.230136986,0.019178082)
		local convertM = #(0,0,43800,730,30.416666667,4.345238095,1,0.083333333)
		local convertYR = #(0,0,525600,8760,365,52.142857143,12,1)
		--local resultLabels = #("ms","s","min","hr","d","wk","m","yr")
		local tempValue = 0.0
		
		case unitConvertRollout.toUnitDD.selection of
		(
			(1):tempValue = convertMS[unitConvertRollout.fromUnitDD.selection]
			(2):tempValue = convertS[unitConvertRollout.fromUnitDD.selection]
			(3):tempValue = convertMIN[unitConvertRollout.fromUnitDD.selection]
			(4):tempValue = convertHR[unitConvertRollout.fromUnitDD.selection]
			(5):tempValue = convertD[unitConvertRollout.fromUnitDD.selection]
			(6):tempValue = convertWK[unitConvertRollout.fromUnitDD.selection]
			(7):tempValue = convertM[unitConvertRollout.fromUnitDD.selection]
			(8):tempValue = convertYR[unitConvertRollout.fromUnitDD.selection]
		)--end case
		
		unitConvertRollout.resultLbl.text = ((unitConvertRollout.unitSpn.value / tempValue) as string)-- + resultLabels[unitConvertRollout.toUnitDD.selection]
	)--end fn
	
	/**********************************************************************************************/
	fn Set_Liquid_Conversion =
	(
		local convertML = #(1,0.001,0.20288413621,0.067628045405,0.033814022701,0.0042267528377,0.0021133764189,0.0010566882094,0.00026417205236)
		local convertL = #(1000,1,202.88413621,67.628045405,33.814022701,4.2267528377,2.1133764189,1.0566882094,0.26417205236)
		local convertTSP = #(4.9289215938,0.0049289215938,1,0.33333333334,0.16666666667,0.020833333334,0.010416666667,0.0052083333334,0.0013020833333)
		local convertTBSP = #(14.786764781,0.014786764781,2.9999999999,1,0.49999999998,0.062499999999,0.031249999999,0.015625,0.0039062499999)
		local convertOZ = #(29.573529563,0.029573529563,6,2,1,0.125,0.062500000001,0.03125,0.0078125000001)
		local convertC = #(236.5882365,0.2365882365,48,16,8,1,0.5,0.25,0.0625)
		local convertPT = #(473.176473,0.473176473,96,32,16,2,1,0.5,0.125)
		local convertQT = #(946.352946,0.946352946,192,64,32,4,2,1,0.25)
		local convertGAL = #(3785.411784,3.785411784,768,256,128,16,8,4,1)
		--local resultLabels = #("mL","L","tsp","tbsp","oz","C","pt","qt","gal")
		local tempValue = 0.0
		
		case unitConvertRollout.toUnitDD.selection of
		(
			(1):tempValue = convertML[unitConvertRollout.fromUnitDD.selection]
			(2):tempValue = convertL[unitConvertRollout.fromUnitDD.selection]
			(3):tempValue = convertTSP[unitConvertRollout.fromUnitDD.selection]
			(4):tempValue = convertTBSP[unitConvertRollout.fromUnitDD.selection]
			(5):tempValue = convertOZ[unitConvertRollout.fromUnitDD.selection]
			(6):tempValue = convertC[unitConvertRollout.fromUnitDD.selection]
			(7):tempValue = convertPT[unitConvertRollout.fromUnitDD.selection]
			(8):tempValue = convertQT[unitConvertRollout.fromUnitDD.selection]
			(9):tempValue = convertGAL[unitConvertRollout.fromUnitDD.selection]
		)--end case
		
		unitConvertRollout.resultLbl.text = ((unitConvertRollout.unitSpn.value / tempValue) as string)-- + resultLabels[unitConvertRollout.toUnitDD.selection]
	)--end fn
	
	/**********************************************************************************************/
	fn Set_Conversion =
	(
		if unitConvertRollout.fromUnitDD.selection == unitConvertRollout.toUnitDD.selection then
			unitConvertRollout.resultLbl.text = (unitConvertRollout.unitSpn.value as string)
		else
			case unitConvertRollout.typeDD.selection of
			(
				(1):Set_Length_Conversion()
				(2):Set_Temp_Conversion()
				(3):Set_Mass_Conversion()
				(4):Set_Time_Conversion()
				(5):Set_Liquid_Conversion()
			)--end case
	)--end fn
	
	/**********************************************************************************************/
	rollout unitConvertRollout "Unit Converter"
	(
		label unitTypeLbl "Unit Type:" pos:[40,9] width:50 height:15
		dropdownlist typeDD "" pos:[95,5] items:#("Length","Temp","Mass","Time","Liquid") width:85 height:6
		
		spinner unitSpn "" pos:[5,32] width:85 range:[-999999999.9,999999999.9,1.0] type:#float scale:0.1
		dropdownlist fromUnitDD "" pos:[95,30] items:#("Millimeter","Centimeter","Meter","Kilometer","Inch","Feet","Yard","Mile") height:10 width:85 selection:1
		edittext resultLbl "" pos:[3,57] width:85 height:15 text:"0.1" readonly:true
		dropdownlist toUnitDD "" pos:[95,55] items:#("Millimeter","Centimeter","Meter","Kilometer","Inch","Feet","Yard","Mile") height:10 width:85 selection:2
		
		-------------------------------------------------------------------------
		on unitSpn changed theValue do Set_Conversion()
		
		-------------------------------------------------------------------------
		on unitConvertRollout moved pos do
			setIniSetting unitConMiniIniFile "Dialog" "Position" (pos as string)
		
		-------------------------------------------------------------------------
		on typeDD selected itemNum do
		(
			local itemArray = #()
			
			case itemNum of
			(
				(1):itemArray = #("Millimeter","Centimeter","Meter","Kilometer","Inch","Feet","Yard","Mile")
				(2):itemArray = #("Celsius","Farrenheit","Kelvin")
				(3):itemArray = #("Gram","Kilogram","Ounce","Pound","Ton")
				(4):itemArray = #("Millisecond","Second","Minute","Hour","Day","Week","Month","Year")
				(5):itemArray = #("Milliliter","Liter","Teaspoon","Tablespoon","Ounce","Cup","Pint","Quart","Gallon")
			)--end case
			
			fromUnitDD.items = toUnitDD.items = itemArray
			fromUnitDD.height = toUnitDD.height = itemArray.count * 16
			fromUnitDD.selection = 1
			toUnitDD.selection = 2
			
			Set_Conversion()
		)--end on
		
		-------------------------------------------------------------------------
		on fromUnitDD selected itemNum do Set_Conversion()
		on toUnitDD selected itemNum do Set_Conversion()
	)--end rollout
	unitConvertRolloutPos = execute (getIniSetting unitConMiniIniFile "Dialog" "Position")
	if unitConvertRolloutPos == OK do unitConvertRolloutPos = [100,100]
	if unitConvertRolloutPos.x > sysinfo.desktopsize.x - 185 do unitConvertRolloutPos.x = sysinfo.desktopsize.x - 190
	if unitConvertRolloutPos.y > sysinfo.desktopsize.y - 140 do unitConvertRolloutPos.y = sysinfo.desktopsize.y - 140
	if unitConvertRolloutPos.x < 0 do unitConvertRolloutPos.x = 0 
	if unitConvertRolloutPos.y < 0 do unitConvertRolloutPos.y = 0
	createDialog unitConvertRollout 185 80 unitConvertRolloutPos.x unitConvertRolloutPos.y
)--end local scope